@@ -3,7 +3,7 @@ BEGIN {
   $App::Pocoirc::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $App::Pocoirc::VERSION = '0.06';
+  $App::Pocoirc::VERSION = '0.07';
 }
 
 use strict;
@@ -25,6 +25,11 @@ sub run {
         close $fh;
     }
 
+    if (!$self->{no_color}) {
+        require Term::ANSIColor;
+        Term::ANSIColor->import();
+    }
+
     if ($self->{daemonize}) {
         require Proc::Daemon;
         eval { Proc::Daemon::Init->() };
@@ -304,7 +309,7 @@ sub irc_raw {
 }
 
 sub _status {
-    my ($self, $message, $context) = @_;
+    my ($self, $message, $context, $error) = @_;
 
     my $stamp = strftime('%Y-%m-%d %H:%M:%S', localtime);
     my $irc; eval { $irc = $context->isa('POE::Component::IRC') };
@@ -312,7 +317,15 @@ sub _status {
     $context = defined $context ? " [$context]" : '';
     
     $message = "$stamp$context $message\n";
-    print $message if !$self->{daemonize};
+
+    if (!$self->{daemonize}) {
+        if ($error) {
+            print colored($message, 'red');
+        }
+        else {
+            print colored($message, 'green');
+        }
+    }
 
     if (defined $self->{cfg}{log_file}) {
         my $fh;
